@@ -33,6 +33,8 @@ class DBConnect:
 
     def write_one_docu(self, docu: dict) -> str:
         try:
+            # 兼容直接指定ID的创建方式
+            docu = handle_db_id(docu)
             # 添加创建时间和更新时间，日期格式
             if not docu.__contains__('creation_time'):
                 docu['creation_time'] = datetime.today()
